@@ -25,12 +25,12 @@ use overload '~~' => sub {
 
 use threads::lite qw/self receive/;
 
-our $VERSION = 0.029_003;
+our $VERSION = 0.029_004;
 
 sub rpc {
 	my ($self, @arguments) = @_;
 	$self->send(self, @arguments);
-	my (undef, @ret) = receive($self);
+	my (undef, @ret) = receiveq($self);
 	return (@ret);
 }
 
@@ -49,7 +49,7 @@ threads::lite::tid - a threads::lite thread id
 
 =head1 VERSION
 
-Version 0.029_003
+Version 0.029_004
 
 =head1 SYNOPSIS
 
