@@ -50,7 +50,7 @@ void queue_init(message_queue* queue) {
 	COND_INIT(&queue->condvar);
 }
 
-void queue_enqueue(message_queue* queue, message* message_, perl_mutex* external_lock) {
+void S_queue_enqueue(pTHX_ message_queue* queue, message* message_, perl_mutex* external_lock) {
 	queue_node* new_entry;
 	MUTEX_LOCK(&queue->mutex);
 	if (external_lock)
@@ -83,7 +83,7 @@ static void queue_shift(message_queue* queue, message* input) {
 		queue->back = NULL;
 }
 
-void queue_dequeue(message_queue* queue, message* input, perl_mutex* external_lock) {
+void S_queue_dequeue(pTHX_ message_queue* queue, message* input, perl_mutex* external_lock) {
 	MUTEX_LOCK(&queue->mutex);
 	if (external_lock)
 		MUTEX_UNLOCK(external_lock);
@@ -96,7 +96,7 @@ void queue_dequeue(message_queue* queue, message* input, perl_mutex* external_lo
 	MUTEX_UNLOCK(&queue->mutex);
 }
 
-bool queue_dequeue_nb(message_queue* queue, message* input, perl_mutex* external_lock) {
+bool S_queue_dequeue_nb(pTHX_ message_queue* queue, message* input, perl_mutex* external_lock) {
 	MUTEX_LOCK(&queue->mutex);
 	if (external_lock)
 		MUTEX_UNLOCK(external_lock);
