@@ -2,7 +2,7 @@ void global_init(pTHX);
 
 mthread* mthread_alloc(PerlInterpreter*);
 void mthread_destroy(mthread*);
-UV queue_alloc();
+UV S_queue_alloc();
 
 void S_thread_send(pTHX_ UV thread_id, message* message);
 void S_queue_send(pTHX_ UV queue_id, message* message);
@@ -11,6 +11,7 @@ void S_queue_receive_nb_(pTHX_ UV queue_id, message* message);
 void thread_add_listener(pTHX, UV talker, UV listener);
 void S_send_listeners(pTHX_ mthread* thread, message* message);
 
+#define queue_alloc() S_queue_alloc(aTHX)
 #define thread_send(id, mess) S_thread_send(aTHX_ id, mess);
 #define queue_send(id, mess) S_queue_send(aTHX_ id, mess);
 #define queue_receive(id, mess) S_queue_receive(aTHX_ id, mess);
